==> sale-1.10.8.jar: revenue/sqls/revenue/MeterReadingManage/handplanOutput.sql <==
select 
	f_userinfo_id,	  //户编号
	f_user_id,			//表编号
	f_user_name,	      //用户姓名
	f_area,			  //片区编号
	f_residential_area, //小区名称
	f_address,		  //用户地址	
	f_surplus_gas,	  //剩余气量
	f_inputtor,		  //抄表员
	f_hand_date,		  //下发日期
	f_meter_base,		//上期指数		
	f_tablebase,			//本期指数
	f_oughtamount,		//应交气量	
	f_oughtfee			//应交金额
from
(
   select  
        d.version,            // 表版本，更新使用 
		d.userinfo_version,	  //户版本	
		d.f_user_name,	      //用户姓名
		d.f_address,		  //用户地址	
		d.f_meter_classify,	  // 气表分类	
		d.f_area,
		d.f_residential_area,
		case when d.f_last_tablebase IS null then d.f_meter_base
		else d.f_last_tablebase end f_meter_base,			//上期指数
	    d.f_price_type,		  //气价类型
		d.f_price_name,		  //气价名称
		d.f_user_id,		  //气表编号
		d.f_userinfo_id,	  //分公司
		d.f_meter_type,		//气表类型
		d.f_price_id,			//气价编号
		d.f_hand_date,			//下发日期
		d.f_input_date,			//录入日期
		d.f_filiale,			//分公司
		d.f_outlets,			//营业忘网点
		case when d.inputtor is null then d.f_inputtor else d.inputtor end as f_inputtor,		//抄表员		
		d.f_user_type,			//用户类型（自动下账时，产生收费记录时使用）
		d.f_gasproperties,      //用气性质（自动下账时，产生收费记录时使用）
		d.f_meter_brand,        //气表品牌（自动下账时，产生收费记录时使用）
		d.f_meter_style,        //气表型号（自动下账时，产生收费记录时使用）
		d.f_meternumber,         //表号（自动下账时，产生收费记录时使用）
		case when (d.f_meternumber = '' or d.f_meternumber is null) then '无表号' else '有表号' end as  meternumber_state,  
		d.f_fire_state,
		d.f_remanent_gas,        // 剩余补气量
		d.h_user_id,				//气表编号
		d.id,						//抄表id		
		d.f_sell_id,			//对应的收费记录
		d.f_tablebase,			//本期指数
		d.f_whether_pay,		//是否缴费
		d.f_oughtamount,		//应交气量	
		d.f_oughtfee,			
		d.f_surplus_gas,
		d.f_haircut_gas,
		d.f_totalsplit_type,
		d.f_share_ratio,
		d.f_share_gas,
		isnull(d.f_meter_source, '手动录入') f_meter_source,
		isnull(d.f_issued_state, '手动下发') f_issued_state,
		isnull(d.f_meter_state,'未下发') f_meter_state,	
		 case when h1.f_hand_date =d.f_hand_date  then 1 else
                        0 end as states,  //抄表单状态
        case when d.f_hand_date <= d.f_operate_date then f_meterstate	
        else '正常' end f_oper_state			// 是否是换表
from (
  select 
        version,				
        u.userinfo_version,		
        u.f_meter_type,     	
        u.f_meter_classify,			
        u.f_user_name,			
        u.f_address,				
        u.f_area,
        u.f_residential_area,
        f_meter_base,					
        u.f_user_id,
        u.f_price_type,			
		u.f_price_name,			
        u.f_userinfo_id,		
        u.f_price_id,			
        u.f_inputtor,				
        u.f_user_type,			
        u.f_gasproperties,      
        u.f_meter_brand,        
        u.f_meter_style,        
        u.f_meternumber,        
        u.f_fire_state,
        u.f_remanent_gas,       
        u.f_initial_base,		
        u.f_filiale,			
        u.f_outlets,
        u.f_totalsplit_type,
		u.f_share_ratio,
        h.f_user_id h_user_id,		
        f_last_tablebase,
        h.id id,	
        f_tablebase,			
        f_whether_pay,
        f_sell_id,		
        f_oughtamount,		
        f_oughtfee,			
        f_hand_date,
        h.f_input_date,
        h.f_meter_state,			
        h.f_inputtor inputtor,
        h.f_share_gas,
        f_meter_source,
        f_issued_state,
        f_surplus_gas,
        f_haircut_gas,
        f_meterState,
        f_operate_date
   from 
   (
       select t.*,
	    case when v.f_operat_type= '换表' then '换表'
	 	else '正常' end f_meterState, v.f_operate_date
       from 
          (select * from V_user_table where f_table_state = '正常' and f_user_state = '正常')  t
          left join
		  (select * from V_record ) v on v.f_user_id=t.f_user_id and v.f_state = '有效'
 ) u
  left join
  (
   select * from V_handplan
   where f_hand_date>='{startDate} 00:00:00' and f_hand_date<='{endDate} 23:59:59' 
      and f_meter_state != '冲正' and  f_meter_state != '已作废'
   ) h on h.f_user_id=u.f_user_id 
) d
left join
    (  
    select MAX(f_hand_date) f_hand_date,max(f_tablebase) f_tablebase,f_user_id from V_handplan where
          f_meter_state != '冲正' and  f_meter_state != '已作废'
    group by f_user_id
     ) h1 on h1.f_user_id=d.f_user_id 
) u
where  {condition}
order by f_user_id

==> sale-3.5.3.jar: revenue/sqls/revenue/MeterReadingManage/handplanOutput.sql <==
select 
	f_userinfo_id,	  //户编号
	f_user_id,			//表编号
	f_user_name,	      //用户姓名
	f_area,			  //片区编号
	f_residential_area, //小区名称
	f_address,		  //用户地址	
	f_surplus_gas,	  //剩余气量
	f_inputtor,		  //抄表员
	f_hand_date,		  //下发日期
	f_meter_base,		//上期指数		
	f_tablebase,			//本期指数
	f_oughtamount,		//应交气量	
	f_oughtfee			//应交金额
from
(
   select  
        d.version,            // 表版本，更新使用 
		d.userinfo_version,	  //户版本	
		d.f_user_name,	      //用户姓名
		d.f_address,		  //用户地址	
		d.f_meter_classify,	  // 气表分类	
		d.f_area,
		d.f_residential_area,
		case when d.f_last_tablebase IS null then d.f_meter_base
		else d.f_last_tablebase end f_meter_base,			//上期指数
	    d.f_price_type,		  //气价类型
		d.f_price_name,		  //气价名称
		d.f_user_id,		  //气表编号
		d.f_userinfo_id,	  //分公司
		d.f_meter_type,		//气表类型
		d.f_price_id,			//气价编号
		d.f_hand_date,			//下发日期
		d.f_input_date,			//录入日期
		case when d.inputtor is null then d.f_inputtor else d.inputtor end as f_inputtor,		//抄表员
		d.f_user_type,			//用户类型（自动下账时，产生收费记录时使用）
		d.f_gasproperties,      //用气性质（自动下账时，产生收费记录时使用）
		d.f_meter_brand,        //气表品牌（自动下账时，产生收费记录时使用）
		d.f_meter_style,        //气表型号（自动下账时，产生收费记录时使用）
		d.f_meternumber,         //表号（自动下账时，产生收费记录时使用）
		case when (d.f_meternumber = '' or d.f_meternumber is null) then '无表号' else '有表号' end as  meternumber_state,  
		d.f_fire_state,
		d.f_remanent_gas,        // 剩余补气量
		d.h_user_id,				//气表编号
		d.id,						//抄表id		
		d.f_sell_id,			//对应的收费记录
		d.f_tablebase,			//本期指数
		d.f_whether_pay,		//是否缴费
		d.f_oughtamount,		//应交气量	
		d.f_oughtfee,			
		d.f_surplus_gas,
		d.f_haircut_gas,
		d.f_totalsplit_type,
		d.f_share_ratio,
		d.f_share_gas,
		{ entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(d.f_meter_source, '手动录入') f_meter_source,
		{ entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(d.f_issued_state, '手动下发') f_issued_state,
		{ entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(d.f_meter_state,'未下发') f_meter_state,
		 case when h1.f_hand_date =d.f_hand_date  then 1 else
                        0 end as states,  //抄表单状态
        case when d.f_hand_date <= d.f_operate_date then f_meterstate	
        else '正常' end f_oper_state			// 是否是换表
from (
  select 
        version,				
        u.userinfo_version,		
        u.f_meter_type,     	
        u.f_meter_classify,			
        u.f_user_name,			
        u.f_address,				
        u.f_area,
        u.f_residential_area,
        f_meter_base,					
        u.f_user_id,
        u.f_price_type,			
		u.f_price_name,			
        u.f_userinfo_id,		
        u.f_price_id,			
        u.f_inputtor,				
        u.f_user_type,			
        u.f_gasproperties,      
        u.f_meter_brand,        
        u.f_meter_style,        
        u.f_meternumber,        
        u.f_fire_state,
        u.f_remanent_gas,       
        u.f_initial_base,		
        u.f_totalsplit_type,
		u.f_share_ratio,
        h.f_user_id h_user_id,		
        f_last_tablebase,
        h.id id,	
        f_tablebase,			
        f_whether_pay,
        f_sell_id,		
        f_oughtamount,		
        f_oughtfee,			
        f_hand_date,
        h.f_input_date,
        h.f_meter_state,			
        h.f_inputtor inputtor,
        h.f_share_gas,
        f_meter_source,
        f_issued_state,
        f_surplus_gas,
        f_haircut_gas,
        f_meterState,
        f_operate_date
   from 
   (
       select t.*,
	    case when v.f_operat_type= '换表' then '换表'
	 	else '正常' end f_meterState, v.f_operate_date
       from 
          (select * from V_user_table where f_table_state = '正常' and f_user_state = '正常')  t
          left join
		  (select * from V_record ) v on v.f_user_id=t.f_user_id and v.f_state = '有效'
 ) u
  left join
  (
   select * from V_handplan
   where f_hand_date>='{startDate} 00:00:00' and f_hand_date<='{endDate} 23:59:59' 
      and f_meter_state != '冲正' and  f_meter_state != '已作废'
   ) h on h.f_user_id=u.f_user_id 
) d
left join
    (  
    select MAX(f_hand_date) f_hand_date,max(f_tablebase) f_tablebase,f_user_id from V_handplan where
          f_meter_state != '冲正' and  f_meter_state != '已作废'
    group by f_user_id
     ) h1 on h1.f_user_id=d.f_user_id 
) u
where  {condition}
order by f_user_id
